# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 13.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V64
65
91
97
123
170
171
186
187
192
215
216
247
248
697
736
741
7424
7462
7468
7517
7522
7526
7531
7544
7545
7615
7680
7936
8305
8306
8319
8320
8336
8349
8490
8492
8498
8499
8526
8527
8544
8585
11360
11392
42786
42888
42891
42944
42946
42955
42997
43008
43824
43867
43868
43877
43878
43882
64256
64263
65313
65339
65345
65371
END
