# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 13.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V38
44
46
58
59
1373
1374
1548
1550
2040
2041
6146
6147
6152
6153
8211
8213
12289
12290
65040
65042
65043
65044
65073
65075
65104
65106
65109
65110
65112
65113
65123
65124
65292
65294
65306
65307
65380
65381
END
